.. commit signature, "date_str author_str sha_str"
   Maintain spacing of "History" and "GitHub Log" titles

History
=======

GitHub Log
----------


* Jan 29, 2019
    - (by: sonofeft)
        - First Created IntroRL with PyHatch

